Module: KicksLiveness::Hooks::Worker Private

Defined in:
lib/kicks_liveness/hooks.rb

Overview

This module is part of a private API. You should avoid using this module if possible, as it may be removed or be changed in the future.

Prepended to Sneakers::Worker. The worker is registered only after a successful subscribe: if subscribe raised, it never reaches the registry and the probe honestly fails.

API:

  • private

Instance Method Summary collapse

Instance Method Details

#runvoid

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

This method returns an undefined value.

API:

  • private



14
15
16
17
# File 'lib/kicks_liveness/hooks.rb', line 14

def run
  super
  Registry.add(self)
end

#stopvoid

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

This method returns an undefined value.

API:

  • private



20
21
22
23
# File 'lib/kicks_liveness/hooks.rb', line 20

def stop
  Registry.remove(self)
  super
end