Class: KicksLiveness::Railtie Private

Inherits:
Rails::Railtie
  • Object
show all
Defined in:
lib/kicks_liveness/railtie.rb

Overview

This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.

Installs the hooks by itself, so a Rails application only needs the configuration block.

to_prepare rather than an initializer: an application's lib is normally managed by Zeitwerk and reloadable, and such constants must not be referenced while the application is initialising.

See Also: